@@ -11,12 +11,12 @@ alias yq='/usr/bin/yq'
 RUN_AS_CONTAINER=${RUN_AS_CONTAINER:-false}
 
 # Profile version used by init-cfg-bundle function
-CMS_PROFILE_VERSION="10.3.8"
-COMMON_PROFILE_VERSION="10.3.8"
-CT_PROFILE_VERSION="10.3.8"
-ES_PROFILE_VERSION="10.3.8"
-DB_PROFILE_VERSION="10.3.8"
-ETCD_PROFILE_VERSION="10.3.8"
+CMS_PROFILE_VERSION="10.3.3"
+COMMON_PROFILE_VERSION="10.3.3"
+CT_PROFILE_VERSION="10.3.3"
+ES_PROFILE_VERSION="10.3.3"
+DB_PROFILE_VERSION="10.3.3"
+ETCD_PROFILE_VERSION="10.3.3"
 
 # Profiles mapping
 declare -A PROFILES
@@ -88,22 +88,6 @@ if [[ $CLOUDPLATFORM == "GCP" ]];then
   GCP_PROJECT=$(get_parameter_value gcp_project_id)
 fi
 
-if [[ $CLOUDPLATFORM == "AWS" ]];then
-  TERRAFORM_FOLDER="tf-aks"
-  TF_DEFAULT_VARIABLES="$SCRIPTPATH/$TERRAFORM_FOLDER/locals.tf"
-  if $RUN_AS_CONTAINER; then
-    CLOUD_ENV="$SCRIPTPATH/data/aws.env"
-  else
-    CLOUD_ENV="$SCRIPTPATH/aws.env"
-  fi
-
-  AWS_EKS_ARN=$(grep OUTPUT_EKS_ARN "${CLOUD_ENV}" | awk -F '=' '{gsub(/"/, "", $2); print $2}')
-  AWS_REGION=$(grep OUTPUT_AWS_REGION "${CLOUD_ENV}" | awk -F '=' '{gsub(/"/, "", $2); print $2}')
-
-` `
-
-
-fi
 
 # 
 ARR_USER_PASSWD=(image_pull_user image_pull_password elasticstack_monitor_user elasticstack_monitor_password elasticstack_manage_user elasticstack_manage_password)
@@ -267,15 +251,7 @@ if [[ $CLOUDPLATFORM == "AZURE" ]];then
 
 fi
 
-if [[ $CLOUDPLATFORM == "AWS" ]];then
-  # Database disk size, since Azure size set above
-  PG_DISK_SIZE=$(get_parameter_value pg_disk_size "30")
-fi
 
-if [[ $CLOUDPLATFORM == "GCP" ]];then
-  # Database disk size, since Azure size set above
-  PG_DISK_SIZE=$(get_parameter_value pg_disk_size "30")
-fi
 
 # Chart Packages
 CMS_CHARTS_PACKAGE="cms-charts-*.tgz"
@@ -372,21 +348,6 @@ start_information_print(){
   echo "  Azure-Disk-StorageClass_SKU=$SC_SKU"|& tee -a $LOG
   echo "  USE_AZURE_FILE_STORAGE=$USE_AZURE_FILE_STORAGE"|& tee -a $LOG
   echo "  USE_AZURE_BLOB_STORAGE=$USE_AZURE_BLOB_STORAGE"|& tee -a $LOG
-  elif [[ $CLOUDPLATFORM == "AWS" ]];then
-
-  AWS_REGION=$(get_parameter_value aws_region)
-
-
-  echo ""|& tee -a $LOG
-  echo "AWS Specific Parameters:"|& tee -a $LOG
-  echo "----------------------------------------"|& tee -a $LOG
-  echo "  K8S_SERVER_VERSION=$K8S_SERVER_VERSION"|& tee -a $LOG
-  echo "  CMS_NODES_K8S_VERSION=$CMS_NODES_K8S_VERSION"|& tee -a $LOG
-  echo "  CLOUD_CLUSTER_INSTANCE_NAME=$CLOUD_CLUSTER_INSTANCE_NAME"|& tee -a $LOG
-  echo "  USE_AWS_FILE_STORAGE=$USE_AWS_FILE_STORAGE"|& tee -a $LOG
-  echo "  USE_AWS_BLOB_STORAGE=$USE_AWS_BLOB_STORAGE"|& tee -a $LOG
-  echo "  AWS_EKS_ARN=$AWS_EKS_ARN"|& tee -a $LOG
-  echo "  AWS_REGION=$AWS_REGION"|& tee -a $LOG
   fi
   echo "=========================================================" |& tee -i -a $LOG
   echo "" |& tee -i -a $LOG
